@@ -7,7 +7,6 @@ import (
 	"fmt"
 	"os"
 	"path/filepath"
-	"runtime/debug"
 	"strings"
 
 	"github.com/derailed/popeye/internal/report"
@@ -55,11 +54,7 @@ func Execute() {
 func doIt(cmd *cobra.Command, args []string) {
 	defer func() {
 		if err := recover(); err != nil {
-			printMsgLogo("DOH", "X", report.ColorOrangish, report.ColorRed)
-			fmt.Printf("\n\nBoom! %v\n", err)
-			log.Error().Msgf("%v", err)
-			log.Error().Msg(string(debug.Stack()))
-			os.Exit(1)
+			pkg.BailOut(err.(error))
 		}
 	}()
 
@@ -300,27 +295,3 @@ func clearScreen() {
 	}
 	fmt.Print("\033[H\033[2J")
 }
-
-func printMsgLogo(msg, eye string, title, logo report.Color) {
-	for i, s := range report.GraderLogo {
-		switch i {
-		case 0, 1, 2:
-			s = strings.Replace(s, "o", string(msg[i]), 1)
-		case 3:
-			s = strings.Replace(s, "a", eye, 1)
-		}
-
-		if i < len(report.Popeye) {
-			fmt.Printf("%s", report.Colorize(report.Popeye[i], title))
-			fmt.Printf("%s", strings.Repeat(" ", 22))
-		} else {
-			if i == 4 {
-				fmt.Printf("%s", report.Colorize("  Biffs`em and Buffs`em!", logo))
-				fmt.Printf("%s", strings.Repeat(" ", 26))
-			} else {
-				fmt.Printf("%s", strings.Repeat(" ", 50))
-			}
-		}
-		fmt.Println(report.Colorize(s, logo))
-	}
-}
