@@ -21,10 +21,5 @@ func ListVersion(ctx context.Context) (*semver.Version, error) {
 		return nil, err
 	}
 
-	rev, err := semver.NewVersion(info.Major + "." + info.Minor)
-	if err != nil {
-		return nil, err
-	}
-
-	return rev, nil
+	return ParseVersion(info)
 }
