@@ -14,7 +14,6 @@ import (
 	"net/http"
 	"os"
 	"path/filepath"
-	"runtime/debug"
 	"time"
 
 	"github.com/derailed/popeye/internal"
@@ -147,7 +146,7 @@ func (p *Popeye) initFactory() error {
 		}
 		ok, err := clt.CanI(client.AllNamespaces, gvr, types.ReadAllAccess...)
 		if !ok || err != nil {
-			return fmt.Errorf("Current user does not have read access for resource %q -- %w", gvr, err)
+			return fmt.Errorf("current user does not have read access for resource %q -- %w", gvr, err)
 		}
 		if _, err := f.ForResource(client.AllNamespaces, gvr); err != nil {
 			return err
@@ -187,9 +186,6 @@ func (p *Popeye) Lint() (int, int, error) {
 	}
 	log.Debug().Msgf("Score [%d]", score)
 
-	if config.IsStrSet(p.flags.S3.Bucket) {
-	}
-
 	return errCount, score, p.dump(true, p.flags.Exhaust())
 }
 
@@ -275,8 +271,7 @@ func (p *Popeye) lint() (int, int, error) {
 func (p *Popeye) runLinter(ctx context.Context, gvr types.GVR, l scrub.Linter, c chan run, cache *scrub.Cache, codes *issues.Codes) {
 	defer func() {
 		if e := recover(); e != nil {
-			log.Error().Msgf("Popeye CHOKED! %#v", e)
-			log.Error().Msgf("%v", string(debug.Stack()))
+			BailOut(e.(error))
 		}
 	}()
 
